Gentelella Alela! |

Welcome,

## John Doe

### Other Charts

## Other Graph types Assorted graph types

USA Vector Map

World Vector Map

#### Easy Pie Chart

Easy pie chart is a jQuery plugin that uses the canvas element to render highly customizable, very easy to implement, simple pie charts for single values.

#### Sparkline Inline Graphs

Yet another great library for inline data visualizations

| Line Graph
| Line Area Graph
| Bar Graph
| Pie Chart
| Discrete chart